@@ -7,6 +7,7 @@ from django.http import Http404
 from django.contrib import messages
 from django.shortcuts import redirect
 from django.urls import resolve
+from django.views.generic.base import RedirectView
 
 from .constants import (
     LOGIN_REQUIRED,
@@ -15,6 +16,7 @@ from .constants import (
     STRICT_POLICY_WHITELIST,
     LOGIN_URL,
     HOME_ROUTE,
+    MEDIA_ROUTE,
 )
 
 class AuthMiddleware:
@@ -85,6 +87,7 @@ class AuthMiddleware:
             or fully_qualified_url_name in LOGIN_EXEMPT_WHITELIST
             or path in LOGIN_EXEMPT_WHITELIST
             or self.login_required_hook(request)
+            or self.verify_media_route(path)
         )
 
 
@@ -115,6 +118,9 @@ class AuthMiddleware:
         # If view, determine if function based or class based
         if view:
 
+            # Get the view class
+            view_class = getattr(view.func, 'view_class', None)
+
             # Determine if request url is exempt.
             current_url_name = view.url_name
             app_name = view.app_name
@@ -124,10 +130,11 @@ class AuthMiddleware:
                 or fully_qualified_url_name in STRICT_POLICY_WHITELIST
                 or path in STRICT_POLICY_WHITELIST
                 or app_name == 'admin'
+                or self.verify_media_route(path)
+                or self.verify_redirect_route(view_class)
             ):
                 exempt = True
 
-            view_class = getattr(view.func, 'view_class', None)
             if view_class:
                 # Get attributes
                 permissions = getattr(view_class, 'permission_required', [])
@@ -163,3 +170,14 @@ class AuthMiddleware:
 
         # Failed somewhere along the way, return false.
         return False
+
+    def verify_media_route(self, path):
+        """Verify that the path of the request is not a MEDIA URL"""
+        return_val = False
+        if MEDIA_ROUTE and MEDIA_ROUTE != '/':
+            return_val = path.startswith(MEDIA_ROUTE)
+        return return_val
+
+    def verify_redirect_route(self, view_class):
+        """Verify that the view class is a RedirectView"""
+        return view_class and view_class == RedirectView
